/* ----------------------------------------------------------------------------
 *         ATMEL Microcontroller Software Support 
 * ----------------------------------------------------------------------------
 * Copyright (c) 2014, Atmel Corporation
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * - Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the disclaimer below.
 *
 * Atmel's name may not be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * DISCLAIMER: THIS SOFTWARE IS PROVIDED BY ATMEL "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT ARE
 * DISCLAIMED. IN NO EVENT SHALL ATMEL BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,
 * OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * ----------------------------------------------------------------------------
 */
#ifndef __GST_G1_BASE_DEC_H__
#define __GST_G1_BASE_DEC_H__

#include <gst/gst.h>
#include <gst/video/gstvideodecoder.h>
#include "gstdwlallocator.h"

#include <ppapi.h>

G_BEGIN_DECLS

#define GST_TYPE_G1_BASE_DEC \
  (gst_g1_base_dec_get_type())
#define GST_G1_BASE_DEC(obj) \
  (G_TYPE_CHECK_INSTANCE_CAST((obj),GST_TYPE_G1_BASE_DEC,GstG1BaseDec))
#define GST_G1_BASE_DEC_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_CAST((klass),GST_TYPE_G1_BASE_DEC,GstG1BaseDecClass))
#define GST_IS_G1_BASE_DEC(obj) \
  (G_TYPE_CHECK_INSTANCE_TYPE((obj),GST_TYPE_G1_BASE_DEC))
#define GST_IS_G1_BASE_DEC_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_TYPE((klass),GST_TYPE_G1_BASE_DEC))

typedef struct _GstG1BaseDec GstG1BaseDec;
typedef struct _GstG1BaseDecClass GstG1BaseDecClass;

struct _GstG1BaseDec {
  GstVideoDecoder parent;

  gpointer codec;
  guint32 dectype;
  PPInst pp;
  PPConfig ppconfig;

  gint rotation;

  gint brightness;
  gint contrast;
  gint saturation;

  guint crop_x;
  guint crop_y;
  guint crop_width;
  guint crop_height;

  guint mask1_x;
  guint mask1_y;
  guint mask1_width;
  guint mask1_height;
  gchar *mask1_location;
  GstG1Memory *mask1_mem;
  
  /* TODO: move to a private */
  GstAllocator *allocator;
};

struct _GstG1BaseDecClass {
  GstVideoDecoderClass parent_class;

  gboolean (*open) (GstG1BaseDec *dec);
  gboolean (*close) (GstG1BaseDec *dec);
  GstFlowReturn (*decode) (GstG1BaseDec *dec, GstVideoCodecFrame *frame);
};

GType gst_g1_base_dec_get_type(void);

void gst_g1_base_dec_config_format (GstG1BaseDec * dec, GstVideoFormatInfo *fmt, 
    gint32 width, gint32 height);
GstFlowReturn gst_g1_base_dec_allocate_output (GstG1BaseDec * dec, 
    GstVideoCodecFrame * frame);
GstFlowReturn gst_g1_base_dec_push_data (GstG1BaseDec *dec, GstVideoCodecFrame *frame);

G_END_DECLS

#endif /*__GST_G1_BASE_DEC_H__*/
