/* ----------------------------------------------------------------------------
 *         ATMEL Microcontroller Software Support 
 * ----------------------------------------------------------------------------
 * Copyright (c) 2014, Atmel Corporation
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * - Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the disclaimer below.
 *
 * Atmel's name may not be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * DISCLAIMER: THIS SOFTWARE IS PROVIDED BY ATMEL "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT ARE
 * DISCLAIMED. IN NO EVENT SHALL ATMEL BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,
 * OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * ----------------------------------------------------------------------------
 */
#include <string.h>

#include "gstg1allocator.h"

GST_DEBUG_CATEGORY_EXTERN (GST_CAT_MEMORY);

GST_DEBUG_CATEGORY_STATIC (gst_g1_allocator_debug);
#define GST_CAT_DEFAULT gst_g1_allocator_debug

static gpointer gst_g1_allocator_map (GstMemory * mem, gsize maxsize,
    GstMapFlags flags);
static void gst_g1_allocator_unmap (GstMemory * mem);

G_DEFINE_TYPE (GstG1Allocator, gst_g1_allocator, GST_TYPE_ALLOCATOR);

static void
gst_g1_allocator_class_init (GstG1AllocatorClass * klass)
{
  GST_DEBUG_CATEGORY_INIT (gst_g1_allocator_debug, "g1allocator",
      0, "G1 Memory Allocator");
}

static void
gst_g1_allocator_init (GstG1Allocator * allocator)
{
  GstAllocator *alloc = GST_ALLOCATOR (allocator);
  GST_CAT_DEBUG (GST_CAT_MEMORY, "init allocator %p", allocator);

  /* Instance specific functions */
  alloc->mem_map = GST_DEBUG_FUNCPTR (gst_g1_allocator_map);
  alloc->mem_unmap = GST_DEBUG_FUNCPTR (gst_g1_allocator_unmap);
}

static gpointer
gst_g1_allocator_map (GstMemory * mem, gsize maxsize, GstMapFlags flags)
{
  GstG1Memory *g1mem;

  g1mem = (GstG1Memory *) mem;

  GST_LOG ("Mapping memory, virtual: %p physical: 0x%08x",
      g1mem->virtaddress, g1mem->physaddress);

  g_return_val_if_fail (GST_IS_G1_ALLOCATOR (mem->allocator), NULL);

  return g1mem->virtaddress;
}

static void
gst_g1_allocator_unmap (GstMemory * mem)
{
  GstG1Memory *g1mem;

  g1mem = (GstG1Memory *) mem;

  g_return_if_fail (GST_IS_G1_ALLOCATOR (mem->allocator));

  GST_LOG ("Unmapping memory, virtual: %p physical: 0x%08x",
      g1mem->virtaddress, g1mem->physaddress);
}

guint32
gst_g1_allocator_get_physical (GstMemory * mem)
{
  GstG1Memory *g1mem;

  g_return_val_if_fail (GST_IS_G1_ALLOCATOR (mem->allocator), 0);

  g1mem = (GstG1Memory *) mem;
  return g1mem->physaddress;
}
