/* ----------------------------------------------------------------------------
 *         ATMEL Microcontroller Software Support 
 * ----------------------------------------------------------------------------
 * Copyright (c) 2014, Atmel Corporation
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * - Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the disclaimer below.
 *
 * Atmel's name may not be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * DISCLAIMER: THIS SOFTWARE IS PROVIDED BY ATMEL "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT ARE
 * DISCLAIMED. IN NO EVENT SHALL ATMEL BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,
 * OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * ----------------------------------------------------------------------------
 */
#ifndef _GST_G1_ALLOCATOR_H_
#define _GST_G1_ALLOCATOR_H_

#include <gst/gst.h>
#include <gst/gstmemory.h>

G_BEGIN_DECLS

#define GST_TYPE_G1_ALLOCATOR \
  (gst_g1_allocator_get_type())
#define GST_IS_G1_ALLOCATOR(obj) \
  (G_TYPE_CHECK_INSTANCE_TYPE((obj),GST_TYPE_G1_ALLOCATOR))
#define GST_IS_G1_ALLOCATOR_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_TYPE((klass),GST_TYPE_G1_ALLOCATOR))
#define GST_G1_ALLOCATOR(obj) \
  (G_TYPE_CHECK_INSTANCE_CAST((obj),GST_TYPE_G1_ALLOCATOR,GstG1Allocator))
#define GST_G1_ALLOCATOR_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_CAST((klass),GST_TYPE_G1_ALLOCATOR,GstG1AllocatorClass))

typedef struct _GstG1Memory GstG1Memory;
typedef struct _GstG1Allocator GstG1Allocator;
typedef struct _GstG1AllocatorClass GstG1AllocatorClass;

struct _GstG1Memory
{
  GstMemory mem;

  gpointer virtaddress;
  guint32 physaddress;
};

struct _GstG1Allocator
{
  GstAllocator parent;
};

struct _GstG1AllocatorClass
{
  GstAllocatorClass parent_class;
};

GType gst_g1_allocator_get_type (void);

/**
 * Returns the physical address of the memory
 *
 * @param mem The GstMemory to query the physical address from. This
 * memory must have been allocated with the GstG1Allocator or subclass.
 *
 * @return The physical address of the data or 0 if the mem was not
 * allocated by a G1 allocator.
 */ 
guint32 gst_g1_allocator_get_physical (GstMemory *mem);

G_END_DECLS
#endif /*_GST_G1_ALLOCATOR_H_*/
